testing

package
v0.0.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EvtType added in v0.0.9

type EvtType string
const (
	EvtTypeSend EvtType = "SEND"
	EvtTypeRecv EvtType = "RECV"
	EvtTypeDrop EvtType = "DROP"
)

type TraceEvent added in v0.0.9

type TraceEvent struct {
	ID          string            `json:"id"`
	MessageID   string            `json:"message_id"`
	Timestamp   int64             `json:"ts"`
	EvtType     EvtType           `json:"evt_type"`
	MsgType     string            `json:"msg_type"`
	From        string            `json:"from"`
	To          string            `json:"to"`
	VectorClock map[string]uint64 `json:"vc"`
	Payload     json.RawMessage   `json:"payload,omitempty"`
}

Directories

Path Synopsis
Package controller implements the DSNet network controller with testing capabilities.
Package controller implements the DSNet network controller with testing capabilities.
Package disttest provides utilities for recording and reporting distributed test results.
Package disttest provides utilities for recording and reporting distributed test results.
Package wrapper provides a WrapperManager to control the lifecycle of binaries on multiple nodes via HTTP requests.
Package wrapper provides a WrapperManager to control the lifecycle of binaries on multiple nodes via HTTP requests.

Jump to