Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TraceEvent ¶ added in v0.0.9
type TraceEvent struct {
ID string `json:"id"`
MessageID string `json:"message_id"`
Timestamp int64 `json:"ts"`
EvtType EvtType `json:"evt_type"`
MsgType string `json:"msg_type"`
From string `json:"from"`
To string `json:"to"`
VectorClock map[string]uint64 `json:"vc"`
Payload json.RawMessage `json:"payload,omitempty"`
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package controller implements the DSNet network controller with testing capabilities.
|
Package controller implements the DSNet network controller with testing capabilities. |
|
Package disttest provides utilities for recording and reporting distributed test results.
|
Package disttest provides utilities for recording and reporting distributed test results. |
|
Package wrapper provides a WrapperManager to control the lifecycle of binaries on multiple nodes via HTTP requests.
|
Package wrapper provides a WrapperManager to control the lifecycle of binaries on multiple nodes via HTTP requests. |
Click to show internal directories.
Click to hide internal directories.